package com.cootek.touchlife;

import com.cootek.touchlife.util.SecurityUtils;
import com.cootek.touchlife.util.WebUtils;
import com.cootek.touchlife.util.StringUtils;
import org.json.JSONObject;

import java.util.HashMap;
import java.util.Map;

/**
 * 客户端。
 * 
 * @author gavin.gu
 * @since 1.0, Jun 08, 2015
 */
public class DefaultTouchlifeClient implements TouchlifeClient {
    public static final String API_VERSION = "apiVersion";
    public static final String APPKEY = "appkey";
    public static final String SELLER_ID = "sellerId";
    public static final String TIMESTAMP = "timestamp";
    public static final String CHARSET = "charset";
    public static final String SIGN_TYPE = "signType";
    public static final String SIGN = "sign";
    
    private String serverUrl;
    private String appkey;
    private String appsecret;
    private String sellerId;
    private String prvKey;
    private String pubKey;
    
    private int connectTimeout = 3000;
    private int readTimeout = 15000;

	public DefaultTouchlifeClient(String serverUrl, String appkey, String appsecret, String sellerId, String prvKey, String pubKey) {
		this.serverUrl = serverUrl;
		this.appkey = appkey;
		this.appsecret = appsecret;
		this.sellerId = sellerId;
		this.prvKey = prvKey;
		this.pubKey = pubKey;
	}

	public  <T extends TouchlifeResponse> T  execute(TouchlifeRequest<T> request) throws ApiException {
		try {
			request.check();

		    StringBuffer reqUrl = new StringBuffer(serverUrl);
            reqUrl.append(request.getApiPath());

            Map<String, Object> params = request.getApiParams();
            params.put(API_VERSION, Constants.API_VERSION);
            params.put(APPKEY, appkey);
            params.put(TIMESTAMP, System.currentTimeMillis()/1000);
            params.put(CHARSET, Constants.CHARSET_UTF8);
            params.put(SIGN_TYPE, request.getSignType());
            if (request.needSellerId()) {
                params.put(SELLER_ID, this.sellerId);
            }
            params.put(SIGN, SecurityUtils.generateSign(params, appsecret, prvKey));

            String res = WebUtils.doPost(reqUrl.toString(), params, Constants.CHARSET_UTF8, connectTimeout, readTimeout, null);
            T response = request.getResponseClass().newInstance();
            response.setBody(res);
            SecurityUtils.verifySign(response.getParams(), appsecret, pubKey);

            return response;
        } catch (Exception e) {
			throw new ApiException(e);
		}
	}
}

