package com.cootek.touchlife;

import com.cootek.touchlife.util.StringUtils;
import org.json.JSONObject;

import java.io.Serializable;
import java.util.Iterator;
import java.util.HashMap;
import java.util.Map;

/**
 * 基础响应信息。
 * 
 * @author gavin.gu
 * @since 1.0, Jun 08, 2015
 */
public abstract class TouchlifeResponse implements Serializable {

	private static final long serialVersionUID = 2934891230409L;

    private static final String RESULT = "result";
    private static final String ERROR_CODE = "errorCode";
    private static final String ERROR_MESSAGE = "errorMessage";

    private String body;
	private Map<String, Object> params;

    public String getBody() {
        return this.body;
    }

    public void setBody(String body) throws Exception {
        this.body = body;
        this.parse();
    }

	public Map<String, Object> getParams() {
		return params;
	}

	public void setParams(Map<String, Object> params) {
		this.params = params;
	}

    protected Object getField(String field) {
        if (this.params.containsKey(field)) {
            return this.params.get(field);
        }

        return null;
    }

    private void parse() throws Exception {
        if (StringUtils.isEmpty(this.body)) {
            return;
        }

        if (this.params == null) {
            this.params = new HashMap<String, Object>();
        }
        this.params.clear();

        JSONObject json = new JSONObject(this.body);
        Iterator<?> it = json.keys();
        while (it.hasNext()) {
            String key = it.next().toString();
            if (!json.isNull(key)) {
                this.params.put(key, json.get(key));
            }
        }

        assert(this.params.containsKey("result"));
        if (Constants.RESULT_FAIL.equals((String)this.params.get(RESULT))) {
            throw new ApiException(StringUtils.objectToString(this.params.get(ERROR_CODE)), StringUtils.objectToString(this.params.get(ERROR_MESSAGE)));
        } else {
            assert (Constants.RESULT_SUCCESS.equals((String)this.params.get(RESULT)));
        }
    }
}

