package com.cootek.touchlife.request;

import com.cootek.touchlife.ApiException;
import com.cootek.touchlife.Constants;
import com.cootek.touchlife.TouchlifeRequest;
import com.cootek.touchlife.util.CheckUtils;
import com.cootek.touchlife.util.StringUtils;
import com.cootek.touchlife.response.OrderOrderPushResponse;

import java.util.HashMap;
import java.util.Map;
import java.util.Date;

public class OrderOrderPushRequest implements TouchlifeRequest<OrderOrderPushResponse> {

	private String userId;
	private String orderId;
	private String orderService;
	private String orderTitle;
	private String orderShortInfo;
	private String orderStatus;
	private Date orderCreateTime;
	private Date orderFinishTime;
	private String orderUrl;
	private String attach;
    private Map<String, Object> apiParams = new HashMap<String, Object>();

    @Override
	public String getApiPath() {
        return "/order/push";
    }

    @Override
    public String getSignType() {
        return Constants.SIGN_TYPE_MD5;
    }

    @Override
    public boolean needSellerId() {
        return false;
    }

    @Override
	public Map<String, Object> getApiParams() {
        return this.apiParams;
    }

    @Override
	public Class<OrderOrderPushResponse> getResponseClass() {
        return OrderOrderPushResponse.class;
    }

    @Override
	public void check() throws ApiException {
        CheckUtils.checkNotEmpty(this.userId, "userId");
        CheckUtils.checkNotEmpty(this.orderId, "orderId");
        CheckUtils.checkMaxLength(this.orderId, 64, "orderId");
        CheckUtils.checkNotEmpty(this.orderService, "orderService");
        CheckUtils.checkMaxLength(this.orderService, 64, "orderService");
        CheckUtils.checkNotEmpty(this.orderTitle, "orderTitle");
        CheckUtils.checkMaxLength(this.orderTitle, 128, "orderTitle");
        CheckUtils.checkNotEmpty(this.orderShortInfo, "orderShortInfo");
        CheckUtils.checkMaxLength(this.orderShortInfo, 512, "orderShortInfo");
        CheckUtils.checkNotEmpty(this.orderStatus, "orderStatus");
        CheckUtils.checkMaxLength(this.orderStatus, 64, "orderStatus");
        CheckUtils.checkNotEmpty(this.orderStatus, "orderCreateTime");
        CheckUtils.checkMaxLength(this.orderStatus, 14, "orderStatus");
        CheckUtils.checkNotEmpty(this.orderUrl, "orderUrl");
        CheckUtils.checkMaxLength(this.orderUrl, 1024, "orderUrl");
    }

	public void setUserId(String userId) {
		this.userId = userId;
		this.apiParams.put("userId", userId);
	}

	public String getUserId() {
		return this.userId;
	}

	public void setOrderId(String orderId) {
		this.orderId = orderId;
		this.apiParams.put("orderId", orderId);
	}

	public String getOrderId() {
		return this.orderId;
	}

	public void setOrderService(String orderService) {
		this.orderService = orderService;
		this.apiParams.put("orderService", orderService);
	}

	public String getOrderService() {
		return this.orderService;
	}

	public void setOrderTitle(String orderTitle) {
		this.orderTitle = orderTitle;
		this.apiParams.put("orderTitle", orderTitle);
	}

	public String getOrderTitle() {
		return this.orderTitle;
	}

	public void setOrderShortInfo(String orderShortInfo) {
		this.orderShortInfo = orderShortInfo;
		this.apiParams.put("orderShortInfo", orderShortInfo);
	}

	public String getOrderShortInfo() {
		return this.orderShortInfo;
	}

	public void setOrderStatus(String orderStatus) {
		this.orderStatus = orderStatus;
		this.apiParams.put("orderStatus", orderStatus);
	}

	public String getOrderStatus() {
		return this.orderStatus;
	}

	public void setOrderCreateTime(Date orderCreateTime) {
		this.orderCreateTime = orderCreateTime;
		this.apiParams.put("orderCreateTime", StringUtils.objectToString(orderCreateTime));
	}

	public Date getOrderCreateTime() {
		return this.orderCreateTime;
	}

	public void setOrderFinishTime(Date orderFinishTime) {
		this.orderFinishTime = orderFinishTime;
		this.apiParams.put("orderFinishTime", StringUtils.objectToString(orderCreateTime));
	}

	public Date getOrderFinishTime() {
		return this.orderFinishTime;
	}

	public void setOrderUrl(String orderUrl) {
		this.orderUrl = orderUrl;
		this.apiParams.put("orderUrl", orderUrl);
	}

	public String getOrderUrl() {
		return this.orderUrl;
	}

	public void setTradeStatus(String attach) {
		this.attach = attach;
		this.apiParams.put("attach", attach);
	}

	public String getAttach() {
		return this.attach;
	}
	public void setAttach(String attach) {
		this.attach = attach;
	}
}

