package com.cootek.touchlife.request;

import com.cootek.touchlife.ApiException;
import com.cootek.touchlife.Constants;
import com.cootek.touchlife.TouchlifeRequest;
import com.cootek.touchlife.util.CheckUtils;
import com.cootek.touchlife.util.StringUtils;
import com.cootek.touchlife.response.TradePayCreateResponse;

import java.util.HashMap;
import java.util.Map;
import java.util.Date;

public class TradePayCreateRequest implements TouchlifeRequest<TradePayCreateResponse> {

	private String accessToken;
	private String userId;
    private String notifyUrl;
    private String tradeNo;
    private String tradeService;
    private String tradeName;
    private String tradeDesc;
    private Long totalFee;
    private Date expireTime;
    private String attach;
    private String tradeStr;
    private Map<String, Object> apiParams = new HashMap<String, Object>();

    @Override
	public String getApiPath() {
        return "/pay/create";
    }

    @Override
    public String getSignType() {
        return Constants.SIGN_TYPE_RSA;
    }

    @Override
    public boolean needSellerId() {
        return true;
    }

    @Override
	public Map<String, Object> getApiParams() {
        return this.apiParams;
    }

    @Override
	public Class<TradePayCreateResponse> getResponseClass() {
        return TradePayCreateResponse.class;
    }

    @Override
	public void check() throws ApiException {
        CheckUtils.checkNotEmpty(this.accessToken, "accessToken");
        CheckUtils.checkNotEmpty(this.userId, "userId");
        CheckUtils.checkNotEmpty(this.notifyUrl, "notifyUrl");
        CheckUtils.checkMaxLength(this.notifyUrl, 1024, "notifyUrl");
        CheckUtils.checkNotEmpty(this.tradeNo, "tradeNo");
        CheckUtils.checkMaxLength(this.tradeNo, 64, "tradeNo");
        CheckUtils.checkNotEmpty(this.tradeService, "tradeService");
        CheckUtils.checkMaxLength(this.tradeService, 64, "tradeService");
        CheckUtils.checkNotEmpty(this.tradeName, "tradeName");
        CheckUtils.checkMaxLength(this.tradeName, 128, "tradeName");
        CheckUtils.checkNotEmpty(this.tradeDesc, "tradeDesc");
        CheckUtils.checkMaxLength(this.tradeDesc, 128, "tradeDesc");
        CheckUtils.checkNotEmpty(this.totalFee, "totalFee");
        CheckUtils.checkMaxValue(this.totalFee, 100000000L, "totalFee");
        CheckUtils.checkMinValue(this.totalFee, 1L, "totalFee");
        if (!StringUtils.isEmpty(this.attach)) {
            CheckUtils.checkMaxLength(this.attach, 1024, "attach");
        }
        CheckUtils.checkNotEmpty(this.tradeStr, "tradeStr");
    }

	public void setAccessToken(String accessToken) {
		this.accessToken = accessToken;
		this.apiParams.put("accessToken", accessToken);
	}

	public String getAccessToken() {
		return this.accessToken;
	}

	public void setUserId(String userId) {
		this.userId = userId;
		this.apiParams.put("userId", userId);
	}

	public String getUserId() {
		return this.userId;
	}

    public void setNotifyUrl(String notifyUrl) {
        this.notifyUrl = notifyUrl;
		this.apiParams.put("notifyUrl", notifyUrl);
    }

	public String getNotifyUrl() {
		return this.notifyUrl;
	}

    public void setTradeNo(String tradeNo) {
        this.tradeNo = tradeNo;
		this.apiParams.put("tradeNo", tradeNo);
    }

	public String getTradeNo() {
		return this.tradeNo;
	}

    public void setTradeService(String tradeService) {
        this.tradeService = tradeService;
		this.apiParams.put("tradeService", tradeService);
    }

	public String getTradeService() {
		return this.tradeService;
	}

    public void setTradeName(String tradeName) {
        this.tradeName = tradeName;
		this.apiParams.put("tradeName", tradeName);
    }

	public String getTradeName() {
		return this.tradeName;
	}

    public void setTradeDesc(String tradeDesc) {
        this.tradeDesc = tradeDesc;
		this.apiParams.put("tradeDesc", tradeDesc);
    }

	public String getTradeDesc() {
		return this.tradeDesc;
	}

    public void setTotalFee(Long totalFee) {
        this.totalFee = totalFee;
		this.apiParams.put("totalFee", totalFee);
    }

	public Long getTotalFee() {
		return this.totalFee;
	}

    public void setExpireTime(Date expireTime) {
        this.expireTime = expireTime;
		this.apiParams.put("expireTime", StringUtils.objectToString(expireTime));
    }

	public Date getExpireTime() {
		return this.expireTime;
	}

    public void setAttach(String attach) {
        this.attach = attach;
		this.apiParams.put("attach", attach);
    }

	public String getAttach() {
		return this.attach;
	}

    public void setTradeStr(String tradeStr) {
        this.tradeStr = tradeStr;
		this.apiParams.put("tradeStr", tradeStr);
    }

	public String getTradeStr() {
		return this.tradeStr;
	}
}

