package com.cootek.touchlife.request;

import com.cootek.touchlife.ApiException;
import com.cootek.touchlife.Constants;
import com.cootek.touchlife.TouchlifeRequest;
import com.cootek.touchlife.util.CheckUtils;
import com.cootek.touchlife.util.StringUtils;
import com.cootek.touchlife.response.TradeRefundApplyResponse;

import java.util.HashMap;
import java.util.Map;
import java.util.Date;

public class TradeRefundApplyRequest implements TouchlifeRequest<TradeRefundApplyResponse> {

	private String userId;
    private String notifyUrl;
    private String transactionId;
    private String refundNo;
    private Long totalFee;
    private Long cashFee;
    private Long refundFee;
    private Map<String, Object> apiParams = new HashMap<String, Object>();

    @Override
	public String getApiPath() {
        return "/refund/apply";
    }

    @Override
    public String getSignType() {
        return Constants.SIGN_TYPE_RSA;
    }

    @Override
    public boolean needSellerId() {
        return true;
    }

    @Override
	public Map<String, Object> getApiParams() {
        return this.apiParams;
    }

    @Override
	public Class<TradeRefundApplyResponse> getResponseClass() {
        return TradeRefundApplyResponse.class;
    }

    @Override
	public void check() throws ApiException {
        CheckUtils.checkNotEmpty(this.userId, "userId");
        CheckUtils.checkNotEmpty(this.notifyUrl, "notifyUrl");
        CheckUtils.checkMaxLength(this.notifyUrl, 1024, "notifyUrl");
        CheckUtils.checkNotEmpty(this.transactionId, "transactionId");
        CheckUtils.checkMaxLength(this.transactionId, 64, "transactionId");
        CheckUtils.checkNotEmpty(this.refundNo, "refundNo");
        CheckUtils.checkMaxLength(this.refundNo, 64, "refundNo");
        CheckUtils.checkNotEmpty(this.totalFee, "totalFee");
        CheckUtils.checkMaxValue(this.totalFee, 100000000L, "totalFee");
        CheckUtils.checkMinValue(this.totalFee, 1L, "totalFee");
        CheckUtils.checkNotEmpty(this.cashFee, "cashFee");
        CheckUtils.checkMaxValue(this.cashFee, 100000000L, "cashFee");
        CheckUtils.checkMinValue(this.cashFee, 1L, "cashFee");
        CheckUtils.checkNotEmpty(this.refundFee, "refundFee");
        CheckUtils.checkMaxValue(this.refundFee, 100000000L, "refundFee");
        CheckUtils.checkMinValue(this.refundFee, 1L, "refundFee");
    }

	public void setUserId(String userId) {
		this.userId = userId;
		this.apiParams.put("userId", userId);
	}

	public String getUserId() {
		return this.userId;
	}

    public void setNotifyUrl(String notifyUrl) {
        this.notifyUrl = notifyUrl;
		this.apiParams.put("notifyUrl", notifyUrl);
    }

	public String getNotifyUrl() {
		return this.notifyUrl;
	}

    public void setTransactionId(String transactionId) {
        this.transactionId = transactionId;
		this.apiParams.put("transactionId", transactionId);
    }

	public String getTransactionId() {
		return this.transactionId;
	}

    public void setRefundNo(String refundNo) {
        this.refundNo = refundNo;
		this.apiParams.put("refundNo", refundNo);
    }

	public String getRefundNo() {
		return this.refundNo;
	}

    public void setTotalFee(Long totalFee) {
        this.totalFee = totalFee;
		this.apiParams.put("totalFee", totalFee);
    }

	public Long getTotalFee() {
		return this.totalFee;
	}

    public void setCashFee(Long cashFee) {
        this.cashFee = cashFee;
		this.apiParams.put("cashFee", cashFee);
    }

	public Long getCashFee() {
		return this.cashFee;
	}

    public void setRefundFee(Long refundFee) {
        this.refundFee = refundFee;
		this.apiParams.put("refundFee", refundFee);
    }

	public Long getRefundFee() {
		return this.refundFee;
	}
}

