package com.cootek.touchlife.util;

import com.cootek.touchlife.Constants;
import com.cootek.touchlife.DefaultTouchlifeClient;
import com.cootek.touchlife.ApiException;

import java.io.ByteArrayInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.security.*;
import java.security.spec.PKCS8EncodedKeySpec;
import java.security.spec.X509EncodedKeySpec;
import java.util.Arrays;
import java.util.Map;

/**
 * 绯荤粺宸ュ叿绫汇��
 * 
 * @author gavin.gu
 * @since 1.0, Jun 08, 2015
 */
public abstract class SecurityUtils {
	private SecurityUtils() {}

	public static String generateSign(Map<String, Object> params, String secret, String privateKey) throws Exception {
        String stringToSigned = paramsToString(params, secret);
        String signType = (String)params.get("signType");

        if (Constants.SIGN_TYPE_MD5.equals(signType)) {
            return signWithMD5(stringToSigned);
        } else if (Constants.SIGN_TYPE_RSA.equals(signType)) {
            return signWithRSA(stringToSigned, privateKey);
        }

        return null;
	}

	public static boolean verifySign(Map<String, Object> params, String secret, String publicKey) throws Exception {
        String stringToSigned = paramsToString(params, secret);
        String signType = (String)params.get("signType");
        String sign = (String)params.get("sign");

        boolean res = false;
        if (Constants.SIGN_TYPE_MD5.equals(signType)) {
            res = StringUtils.equals(sign, signWithMD5(stringToSigned));
        } else if (Constants.SIGN_TYPE_RSA.equals(signType)) {
            res = verifyWithRSA(stringToSigned, sign, publicKey);
        }

        if (!res) {
            throw new ApiException(Constants.ERROR_CODE_SIGNATURE_INVALID, "server-error:Invalid signature");
        }

        return res;
    }

    private static String paramsToString(Map<String, Object> params, String secret) {
		String[] keys = params.keySet().toArray(new String[0]);
		Arrays.sort(keys);
		StringBuilder query = new StringBuilder();
		for (String key : keys) {
            if (!DefaultTouchlifeClient.SIGN.equals(key) && !DefaultTouchlifeClient.SIGN_TYPE.equals(key)) {
                Object value = params.get(key);
                String strValue = StringUtils.objectToString(value);
		        if (!(strValue == null || (strValue.length()) == 0)) {
                    query.append(key).append("=").append(value).append("&");
                }
            }
		}
		query.append("appsecret=").append(secret);

        return query.toString();
    }

	private static String signWithMD5(String data) throws IOException {
		byte[] bytes = null;
		try {
			MessageDigest md = MessageDigest.getInstance("MD5");
			bytes = md.digest(data.getBytes(Constants.CHARSET_UTF8));
		} catch (GeneralSecurityException gse) {
			throw new IOException(gse);
		}

		StringBuilder sign = new StringBuilder();
		for (int i = 0; i < bytes.length; i++) {
			String hex = Integer.toHexString(bytes[i] & 0xFF);
			if (hex.length() == 1) {
				sign.append("0");
			}
			sign.append(hex.toUpperCase());
		}
		return sign.toString();
	}

	public static String signWithRSA(String content, String privateKey) throws Exception {
		try {
            InputStream ins = new ByteArrayInputStream(privateKey.getBytes());
		    KeyFactory keyFactory = KeyFactory.getInstance(Constants.SIGN_TYPE_RSA);
		    byte[] encodedKey = StreamUtils.readText(ins).getBytes();
		    encodedKey = Base64.decode(encodedKey);
		    PrivateKey priKey = keyFactory.generatePrivate(new PKCS8EncodedKeySpec(encodedKey));
			java.security.Signature signature = java.security.Signature.getInstance(Constants.SIGN_ALGORITHMS);
			signature.initSign(priKey);
			signature.update(content.getBytes(Constants.CHARSET_UTF8));
			byte[] signed = signature.sign();
			return Base64.encodeToString(signed, false);
		} catch (Exception e) {
			throw e;
		}
	}

	public static boolean verifyWithRSA(String content, String sign, String publicKey) throws Exception {
		try {
            InputStream ins = new ByteArrayInputStream(publicKey.getBytes());
		    KeyFactory keyFactory = KeyFactory.getInstance(Constants.SIGN_TYPE_RSA);
		    byte[] encodedKey = StreamUtils.readText(ins).getBytes();
		    encodedKey = Base64.decode(encodedKey);
		    PublicKey pubKey = keyFactory.generatePublic(new X509EncodedKeySpec(encodedKey));
			Signature signature = Signature.getInstance(Constants.SIGN_ALGORITHMS);
			signature.initVerify(pubKey);
			signature.update(content.getBytes(Constants.CHARSET_UTF8));
            return signature.verify(Base64.decode(sign));
		} catch (Exception e) {
			throw e;
		}
	}
}

