﻿using System;
using System.Collections;
using System.Collections.Generic;
using System.Text;
using Touchlife.Api.Util;


namespace Touchlife.Api
{
	/// <summary>
	/// Touch Life 默认客户端
	/// 需传输构造函数传入的私钥和公钥
	/// 如果请求类签名方式为MD5则传入私钥和公钥的字符串值.
	/// 如果请求类签名方式为RSA则传入私钥和公钥的文件路径.
	/// </summary>
	public class DefaultTouchlifeClient: ITouchlifeClient
	{
        public const string API_VERSION = "apiVersion";
        public const string APPKEY = "appkey";
        public const string SELLER_ID = "sellerId";
        public const string TIMESTAMP = "timestamp";
        public const string CHARSET = "charset";
        public const string SIGN_TYPE = "signType";
        public const string SIGN = "sign";

        private string serverUrl;
        private string appkey;
        private string appsecret;
        private string sellerId;
        private string prvKey;
        private string pubKey;
        
        
        public DefaultTouchlifeClient(string serverUrl, string appkey, string appsecret, string sellerId, string prvKey, string pubKey)
        {
            this.serverUrl = serverUrl;
            this.appkey = appkey;
            this.appsecret = appsecret;
            this.sellerId = sellerId;
            this.prvKey = prvKey;
            this.pubKey = pubKey;
        }
        
        
		public T Execute<T>(ITouchlifeRequest<T> request) where T : TouchlifeResponse
		{
			WebUtils web = new WebUtils();
			try
			{
                request.Validate();
                
                string reqUrl = this.serverUrl + request.GetApiPath();
                
                IDictionary<string, object> parameters = request.GetParameters();
                parameters.Add(API_VERSION, Constants.API_VERSION);
                parameters.Add(APPKEY, appkey);
                parameters.Add(TIMESTAMP, GetCurrentTimeSeconds());
                parameters.Add(CHARSET, Constants.CHARSET_UTF8);
                parameters.Add(SIGN_TYPE, request.GetSignType());
                if (request.NeedSellerId) 
                {
                    parameters.Add(SELLER_ID, this.sellerId);
                }
                parameters.Add(SIGN, SecurityUtils.GenerateSign(parameters, this.appsecret, this.prvKey));
                
				string res = web.DoPost(reqUrl, parameters);
				T response = Activator.CreateInstance<T>();
				response.Body = res;
                response.ParseFrom();
                SecurityUtils.VerifySign(response.Parameters, appsecret, pubKey);

                return response;
			}
			catch(Exception ex)
			{
				throw new ApiException(ex.Message, ex);
			}
		}
		
        public static long GetCurrentTimeSeconds()
        {
            return (long)DateTime.UtcNow.Subtract(new DateTime(1970, 1, 1)).TotalSeconds;
        }
	}
}
