﻿using System;
using Touchlife.Api;
using System.Collections.Generic;

namespace Touchlife.Api
{
	/// <summary>
	/// 订单推送请求类
	/// </summary>
	public class OrderOrderPushRequest : ITouchlifeRequest<OrderOrderPushResponse>
	{
		private string accessToken;
		public  string AccessToken
		{
			get
			{
				return this.accessToken;
			}
			set
			{
				this.accessToken = value;
				Parameters["accessToken"] = value;
			}
		}
		
		private string userId;
		public string UserId
		{
			get
			{
				return this.userId;
			}
			set
			{
				this.userId = value;
				Parameters["userId"] = value;
			}
		}
		
		private string orderId;
		public string OrderId
		{
			get
			{
				return this.orderId;
			}
			set
			{
				this.orderId = value;
				Parameters["orderId"] = value;
			}
		}
		
		private string orderService;
		public string OrderService
		{
			get
			{
				return this.orderService;
			}
			set
			{
				this.orderService = value;
				Parameters["orderService"] = value;
			}
		}
		
		private string orderTitle;
		public string OrderTitle
		{
			get
			{
				return this.orderTitle;
			}
			set
			{
				this.orderTitle = value;
				Parameters["orderTitle"] = value;
			}
		}
		
		private string orderShortInfo;
		public string OrderShortInfo
		{
			get
			{
				return this.orderShortInfo;
			}
			set
			{
				this.orderShortInfo = value;
				Parameters["orderShortInfo"] = value;
			}
		}
		
		private string orderStatus;
		public string OrderStatus
		{
			get
			{
				return this.orderStatus;
			}
			set
			{
				this.orderStatus = value;
				Parameters["orderStatus"] = value;
			}
		}
		
		private DateTime orderCreateTime;
		public DateTime OrderCreateTime
		{
			get
			{
				return this.orderCreateTime;
			}
			set
			{
				this.orderCreateTime = value;
				Parameters["orderCreateTime"] = StringUtils.Datetime2Str(value);
			}
		}
		
		private DateTime orderFinishTime;
		public DateTime OrderFinishTime
		{
			get
			{
				return this.orderFinishTime;
			}
			set
			{
				this.orderFinishTime = value;
				Parameters["orderFinishTime"] = StringUtils.Datetime2Str(value);
			}
		}
		
		private string orderUrl;
		public string OrderUrl
		{
			get
			{
				return this.orderUrl;
			}
			set
			{
				this.orderUrl = value;
				Parameters["orderUrl"] = value;
			}
		}
			
		private string attach;
		public string Attach
		{
			get
			{
				return this.attach;
			}
			set
			{
				this.attach = value;
				Parameters["attach"] = value;
			}
		}
		
		public IDictionary<string, object> Parameters{get; set;}
		
		
		public OrderOrderPushRequest()
		{
			this.Parameters = new Dictionary<string, object>();
//			this.AccessToken = string.Empty;
		}
		
		public OrderOrderPushRequest(string accessToken)
		{
			this.Parameters = new Dictionary<string, object>();
			this.AccessToken = accessToken;
		}
		
		public bool NeedSellerId 
		{
			get 
			{
				return false;
			}
		}
		
		public string GetApiPath()
		{
			return "/order/push";
		}
		
		public string GetSignType()
		{
			return Constants.SIGN_TYPE_MD5;
		}
		
		public IDictionary<string, object> GetParameters()
		{
			return this.Parameters;
		}
		
		public Type GetResponseType()
		{
			return this.GetType();
		}
		
		public void Validate()
		{
	        CheckUtils.CheckNotEmpty(this.UserId, "userId");
	        CheckUtils.CheckNotEmpty(this.OrderId, "orderId");
	        CheckUtils.CheckMaxLength(this.OrderId, 64, "orderId");
	        CheckUtils.CheckNotEmpty(this.OrderService, "orderService");
	        CheckUtils.CheckMaxLength(this.OrderService, 64, "orderService");
	        CheckUtils.CheckNotEmpty(this.OrderTitle, "orderTitle");
	        CheckUtils.CheckMaxLength(this.OrderTitle, 128, "orderTitle");
	        CheckUtils.CheckNotEmpty(this.OrderShortInfo, "orderShortInfo");
	        CheckUtils.CheckMaxLength(this.OrderShortInfo, 512, "orderShortInfo");
	        CheckUtils.CheckNotEmpty(this.OrderStatus, "orderStatus");
	        CheckUtils.CheckMaxLength(this.OrderStatus, 64, "orderStatus");
	        CheckUtils.CheckNotEmpty(this.OrderUrl, "orderUrl");
	        CheckUtils.CheckMaxLength(this.OrderUrl, 1024, "orderUrl");
		}
	}
}
