﻿using System;
using System.Collections.Generic;

namespace Touchlife.Api
{
	/// <summary>
	/// 创建订单请求类
	/// </summary>
	public class TradePayCreateRequest: ITouchlifeRequest<TradePayCreateResponse>
	{
		private string accessToken;
		public  string AccessToken
		{
			get
			{
				return this.accessToken;
			}
			set
			{
				this.accessToken = value;
				Parameters["accessToken"] = value;
			}
		}
		
		private string userId;
		public string UserId
		{
			get
			{
				return this.userId;
			}
			set
			{
				this.userId = value;
				Parameters["userId"] = value;
			}
		}
		
		private string notifyUrl;
		public string NotifyUrl
		{
			get
			{
				return this.notifyUrl;
			}
			set
			{
				this.notifyUrl = value;
				Parameters["notifyUrl"] = value;
			}
		}
		
		private string tradeNo;
		public string TradeNo
		{
			get
			{
				return this.tradeNo;
			}
			set
			{
				this.tradeNo = value;
				Parameters["tradeNo"] = value;
			}
		}	

		private string tradeService;
		public string TradeService
		{
			get
			{
				return this.tradeService;
			}
			set
			{
				this.tradeService = value;
				Parameters["tradeService"] = value;
			}
		}		
		
		private string tradeName;
		public string TradeName
		{
			get
			{
				return this.tradeName;
			}
			set
			{
				this.tradeName = value;
				Parameters["tradeName"] = value;
			}
		}		
		
		private string tradeDesc;
		public string TradeDesc
		{
			get
			{
				return this.tradeDesc;
			}
			set
			{
				this.tradeDesc = value;
				Parameters["tradeDesc"] = value;
			}
		}	
		
		private long totalFee;
		public long TotalFee
		{
			get
			{
				return this.totalFee;
			}
			set
			{
				this.totalFee = value;
				Parameters["totalFee"] = value;
			}
		}
		
		private DateTime expireTime;
		public DateTime ExpireTime
		{
			get
			{
				return this.expireTime;
			}
			set
			{
				this.expireTime = value;
				Parameters["expireTime"] = StringUtils.Datetime2Str(value);;
			}
		}
		
		private string attach;
		public string Attach
		{
			get
			{
				return this.attach;
			}
			set
			{
				this.attach = value;
				Parameters["attach"] = value;
			}
		}

		private string tradeStr;
		public string TradeStr
		{
			get
			{
				return this.tradeStr;
			}
			set
			{
				this.tradeStr = value;
				Parameters["tradeStr"] = value;
			}
		}		
		
		public IDictionary<string, object> Parameters{get; set;}
		
		public TradePayCreateRequest()
		{
			this.Parameters = new Dictionary<string, object>();
//			this.AccessToken = string.Empty;
		}
		
		public TradePayCreateRequest(string accessToken)
		{
			this.Parameters = new Dictionary<string, object>();
			this.AccessToken = accessToken;
		}		
		
		public bool NeedSellerId 
		{
			get
			{
				return true;
			}
		}
		
		public string GetApiPath()
		{
        	return "/pay/create";
		}
		
		public string GetSignType()
		{
        	return Constants.SIGN_TYPE_RSA;
		}
		
		public IDictionary<string, object> GetParameters()
		{
			return this.Parameters;
		}
		
		public Type GetResponseType()
		{
			return this.GetType();
		}
		
		public void Validate()
		{
	        CheckUtils.CheckNotEmpty(this.AccessToken, "AccessToken");
	        CheckUtils.CheckNotEmpty(this.UserId, "UserId");
	        CheckUtils.CheckNotEmpty(this.NotifyUrl, "NotifyUrl");
	        CheckUtils.CheckMaxLength(this.NotifyUrl, 1024, "NotifyUrl");
	        CheckUtils.CheckNotEmpty(this.TradeNo, "TradeNo");
	        CheckUtils.CheckMaxLength(this.TradeNo, 64, "TradeNo");
	        CheckUtils.CheckNotEmpty(this.TradeService, "TradeService");
	        CheckUtils.CheckMaxLength(this.TradeService, 64, "TradeService");
	        CheckUtils.CheckNotEmpty(this.TradeName, "TradeName");
	        CheckUtils.CheckMaxLength(this.TradeName, 128, "TradeName");
	        CheckUtils.CheckNotEmpty(this.TradeDesc, "TradeDesc");
	        CheckUtils.CheckMaxLength(this.TradeDesc, 128, "TradeDesc");
	        CheckUtils.CheckNotEmpty(this.TotalFee, "TotalFee");
	        CheckUtils.CheckMaxValue(this.TotalFee, 100000000L, "TotalFee");
	        CheckUtils.CheckMinValue(this.TotalFee, 1L, "TotalFee");
	        if (!string.IsNullOrEmpty(this.Attach)) 
	        {
	            CheckUtils.CheckMaxLength(this.Attach, 1024, "Attach");
	        }
	        CheckUtils.CheckNotEmpty(this.TradeStr, "TradeStr");
		}
	}
}
