﻿using System;
using System.Collections.Generic;

namespace Touchlife.Api
{
	/// <summary>
	/// 退款请求类
	/// </summary>
	public class TradeRefundApplyRequest : ITouchlifeRequest<TradeRefundApplyResponse>
	{
		private string accessToken;
		public  string AccessToken
		{
			get
			{
				return this.accessToken;
			}
			set
			{
				this.accessToken = value;
				Parameters["accessToken"] = value;
			}
		}
		
		private string userId;
		public string UserId
		{
			get
			{
				return this.userId;
			}
			set
			{
				this.userId = value;
				Parameters["userId"] = value;
			}
		}
		
		private string notifyUrl;
		public string NotifyUrl
		{
			get
			{
				return this.notifyUrl;
			}
			set
			{
				this.notifyUrl = value;
				Parameters["notifyUrl"] = value;
			}
		}
		
		private string transactionId;
		public string TransactionId
		{
			get
			{
				return this.transactionId;
			}
			set
			{
				this.transactionId = value;
				Parameters["transactionId"] = value;
			}
		}
		
		private string refundNo;
		public string RefundNo
		{
			get
			{
				return this.refundNo;
			}
			set
			{
				this.refundNo = value;
				Parameters["refundNo"] = value;
			}
		}
		
		private long totalFee;
		public long TotalFee
		{
			get
			{
				return this.totalFee;
			}
			set
			{
				this.totalFee = value;
				Parameters["totalFee"] = value;
			}
		}
		
		private long cashFee;
		public long CashFee
		{
			get
			{
				return this.cashFee;
			}
			set
			{
				this.cashFee = value;
				Parameters["cashFee"] = value;
			}
		}
		
		private long refundFee;
		public long RefundFee
		{
			get
			{
				return this.refundFee;
			}
			set
			{
				this.refundFee = value;
				Parameters["refundFee"] = value;
			}
		}
		
		public IDictionary<string, object> Parameters{get; set;}
		
		public TradeRefundApplyRequest()
		{
			this.Parameters = new Dictionary<string, object>();
//			this.AccessToken = string.Empty;
		}
		
		public TradeRefundApplyRequest(string accessToken)
		{
			this.Parameters = new Dictionary<string, object>();
			this.AccessToken = accessToken;
		}
		
		public bool NeedSellerId 
		{
			get 
			{
				return true;
			}
		}
		
		public string GetApiPath()
		{
        	return "/refund/apply";
		}
		
		public string GetSignType()
		{
			return Constants.SIGN_TYPE_RSA;
		}
		
		public System.Collections.Generic.IDictionary<string, object> GetParameters()
		{
			return this.Parameters;
		}
		
		public Type GetResponseType()
		{
			return this.GetType();
		}
		
		public void Validate()
		{
	        CheckUtils.CheckNotEmpty(this.UserId, "userId");
	        CheckUtils.CheckNotEmpty(this.NotifyUrl, "notifyUrl");
	        CheckUtils.CheckMaxLength(this.NotifyUrl, 1024, "notifyUrl");
	        CheckUtils.CheckNotEmpty(this.TransactionId, "transactionId");
	        CheckUtils.CheckMaxLength(this.TransactionId, 64, "transactionId");
	        CheckUtils.CheckNotEmpty(this.RefundNo, "refundNo");
	        CheckUtils.CheckMaxLength(this.RefundNo, 64, "refundNo");
	        CheckUtils.CheckNotEmpty(this.TotalFee, "totalFee");
	        CheckUtils.CheckMaxValue(this.TotalFee, 100000000L, "totalFee");
	        CheckUtils.CheckMinValue(this.TotalFee, 1L, "totalFee");
	        CheckUtils.CheckNotEmpty(this.CashFee, "cashFee");
	        CheckUtils.CheckMaxValue(this.CashFee, 100000000L, "cashFee");
	        CheckUtils.CheckMinValue(this.CashFee, 1L, "cashFee");
	        CheckUtils.CheckNotEmpty(this.RefundFee, "refundFee");
	        CheckUtils.CheckMaxValue(this.RefundFee, 100000000L, "refundFee");
	        CheckUtils.CheckMinValue(this.RefundFee, 1L, "refundFee");
		}
	}
}
