﻿
using System;

namespace Touchlife.Api
{
	/// <summary>
	/// Description of CheckUtils.
	/// </summary>
	public class CheckUtils
	{
		public static void CheckNotEmpty(object value, string fieldName)
		{
			if(null == value)
			{
				throw new ApiException(Constants.ERROR_CODE_ARGUMENTS_MISSING, "client-error:Missing required arguments:" + fieldName + "");
			}
			else if (value.GetType() == typeof(string))
			{
				if(string.IsNullOrEmpty(value.ToString()))
				{
					throw new ApiException(Constants.ERROR_CODE_ARGUMENTS_MISSING, "client-error:Missing required arguments:" + fieldName + "");
				}
				
			}
		}
		
		public static void CheckMaxLength(string value, int maxLength, string fieldName)
		{
			if (value != null) 
			{
				if (value.Length > maxLength) 
				{
					throw new ApiException(Constants.ERROR_CODE_ARGUMENTS_INVALID,
					                       "client-error:Invalid arguments:the string length of " + fieldName + " can not be larger than " + maxLength + ".");
				}
			}
		}
		
		public static void CheckMaxValue(long value, long maxValue, string fieldName) 
		{
			if (value != 0L) 
			{
				if (value > maxValue) 
				{
					throw new ApiException(Constants.ERROR_CODE_ARGUMENTS_INVALID, "client-error:Invalid arguments:the value of " + fieldName + " can not be larger than " + maxValue + ".");
				}
			}
		}
		
		public static void CheckMinValue(long value, long minValue, string fieldName)
		{
			if (value != 0L) 
			{
				if (value < minValue) 
				{
					throw new ApiException(Constants.ERROR_CODE_ARGUMENTS_INVALID, "client-error:Invalid arguments:the value of " + fieldName + " can not be less than " + minValue + ".");
				}
			}
		}
		
		public static void CheckMaxValue(double value, double maxValue, string fieldName)
		{
			if (value != 0L) 
			{
				if (value > maxValue) 
				{
					throw new ApiException(Constants.ERROR_CODE_ARGUMENTS_INVALID, "client-error:Invalid arguments:the value of " + fieldName + " can not be larger than " + maxValue + ".");
				}
			}
		}
	
		public static void CheckMinValue(double value, double minValue, string fieldName)
		{
			if (value != 0d)
			{
				if (value < minValue)
				{
					throw new ApiException(Constants.ERROR_CODE_ARGUMENTS_INVALID, "client-error:Invalid arguments:the value of " + fieldName + " can not be less than " + minValue + ".");
				}
			}
		}
		
	}
}
