﻿using System;
using System.Collections;
using System.Collections.Generic;
using System.IO;
using System.Net;
using System.Text;
using System.Web;
using System.Net.Security;
using System.Security.Authentication;
using System.Security.Cryptography.X509Certificates;
using System.Web.Script.Serialization;

namespace Touchlife.Api.Util
{
    public sealed class WebUtils
    {
        private int _timeout = 60000;

        public int Timeout
        {
            get { return _timeout; }
            set { _timeout = value; }
        }

        public string DoPost(string url, IDictionary<string, object> parameters)
        {
            HttpWebRequest req = GetWebRequest(url, "POST");
            req.ContentType = "application/json;charset=utf-8";

           	JavaScriptSerializer serializer = new JavaScriptSerializer();
           	string strJson = serializer.Serialize(parameters);
            
           	byte[] postData = Encoding.UTF8.GetBytes(strJson);
            System.IO.Stream reqStream = req.GetRequestStream();
            reqStream.Write(postData, 0, postData.Length);
            reqStream.Close();

            HttpWebResponse rsp = (HttpWebResponse)req.GetResponse();
            Encoding encoding = Encoding.GetEncoding(rsp.CharacterSet);
            return GetResponseAsString(rsp, encoding);
        }

        public bool CheckValidationResult(object sender, X509Certificate certificate, X509Chain chain, SslPolicyErrors errors)
        {
            return true;
        }

        public HttpWebRequest GetWebRequest(string url, string method)
        {
            HttpWebRequest req = null;
            if (url.Contains("https"))
            {
                ServicePointManager.ServerCertificateValidationCallback = new RemoteCertificateValidationCallback(CheckValidationResult);
                req = (HttpWebRequest)WebRequest.CreateDefault(new Uri(url));
            }
            else
            {
                req = (HttpWebRequest)WebRequest.Create(url);
            }

            req.ServicePoint.Expect100Continue = false;
            req.Method = method;
            req.KeepAlive = true;
            req.UserAgent = "Touchlife4Net";
            req.Timeout = this._timeout;

            return req;
        }

        public string GetResponseAsString(HttpWebResponse rsp, Encoding encoding)
        {
            System.IO.Stream stream = null;
            StreamReader reader = null;

            try
            {
                stream = rsp.GetResponseStream();
                reader = new StreamReader(stream, encoding);
                return reader.ReadToEnd();
            }
            finally
            {
                if (reader != null) 
                {
                	reader.Close();
                }
                if (stream != null) 
                {
                	stream.Close();
                }
                if (rsp != null)
                {
                	rsp.Close();
                }
            }
        }  
        
    }
}

