<?php
class TouchlifeClient
{
    public $connectUrl;
	public $appkey;
    public $appsecret;
    public $sellerId;
    public $prvKeyPath;
    public $pubKeyPath;

	protected $connectTimeout = 3000;
	protected $readTimeout = 60000;

    protected $charset = "UTF-8";
	protected $apiVersion = "1.1";
	protected $sdkVersion = "20150603";

	protected function generateSign($params)
	{
        $stringToBeSigned = $this->paramsToString($params);
        $signType = $params["signType"];
        if ($signType == "MD5")
        {
            return strtoupper(md5($stringToBeSigned));
        }
        else if ($signType == "RSA")
        {
            $prvKey = file_get_contents($this->prvKeyPath);
            $key = openssl_get_privatekey($prvKey);
            openssl_sign($stringToBeSigned, $sign, $key);
            openssl_free_key($key);
            return base64_encode($sign);
        }
	}

	protected function verifySign($params)
	{
        $stringToBeSigned = $this->paramsToString($params);
        $signType = $params["signType"];
        $sign = $params["sign"];

        if ($signType == "MD5")
        {
            return $sign == strtoupper(md5($stringToBeSigned));
        }
        else if ($signType == "RSA")
        {
            $pubKey = file_get_contents($this->pubKeyPath);
            $key = openssl_get_publickey($pubKey);
            $result = (bool)openssl_verify($stringToBeSigned, base64_decode($sign), $key);
            openssl_free_key($key);
            return $result;
        }

        return false;
	}

    protected function paramsToString($params)
    {
		ksort($params);

		$sortedString = "";
		foreach ($params as $k => $v)
		{
            $v = (string)$v;
			if("sign" !== $k && "signType" !== $k && strlen($v) > 0)
			{
				$sortedString .= "$k=$v&";
			}
		}
		$sortedString .= "appsecret=$this->appsecret";

        return $sortedString;
    }

	public function curl($url, $postFields = null)
	{
		$ch = curl_init();
		curl_setopt($ch, CURLOPT_URL, $url);
		curl_setopt($ch, CURLOPT_FAILONERROR, false);
		curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);

		if ($this->readTimeout) {
			curl_setopt($ch, CURLOPT_TIMEOUT, $this->readTimeout);
		}
		if ($this->connectTimeout) {
			curl_setopt($ch, CURLOPT_CONNECTTIMEOUT, $this->connectTimeout);
		}

		if(strlen($url) > 5 && strtolower(substr($url,0,5)) == "https" ) {
			curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
			curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, false);
		}

		if (is_array($postFields) && 0 < count($postFields))
		{
			$header = array("content-type: application/json; charset=UTF-8");
			curl_setopt($ch, CURLOPT_POST, true);
			curl_setopt($ch,CURLOPT_HTTPHEADER,$header);
			curl_setopt($ch, CURLOPT_POSTFIELDS, json_encode($postFields));
		}
		$reponse = curl_exec($ch);
		
		if (curl_errno($ch))
		{
			throw new Exception(curl_error($ch), 0);
		}
		else
		{
			$httpStatusCode = curl_getinfo($ch, CURLINFO_HTTP_CODE);
			if (200 !== $httpStatusCode)
			{
				throw new Exception($reponse, $httpStatusCode);
			}
		}
		curl_close($ch);
		return $reponse;
	}

	public function execute($request)
    {
        try 
        {
			$request->check();
        } 
        catch (Exception $e) 
        {
			$result->code = $e->getCode();
			$result->message = $e->getMessage();
			return $result;
		}

		$apiParams = $request->getApiParas();
		$apiParams["apiVersion"] = $this->apiVersion;
		$apiParams["appkey"] = $this->appkey;
		$apiParams["sellerId"] = $this->sellerId;
		$apiParams["timestamp"] = time();
		$apiParams["charset"] = $this->charset;
		$apiParams["signType"] = $request->getSignType();
		$apiParams["sign"] = $this->generateSign($apiParams);

		$requestUrl = $this->connectUrl . $request->getApiPath();
		try
		{
			$resp = $this->curl($requestUrl, $apiParams);
		}
		catch (Exception $e)
		{
			throw $e;
	    }

        return $this->onResponse($resp);
	}

	public function onResponse($resp)
    {
        try
        {
            $respObject = json_decode($resp, true);
            if (null !== $respObject)
            {
                if ($respObject["result"] == "SUCCESS")
                {
                    if (false == $this->verifySign($respObject))
                    {
		                throw new Exception("verify-error:Invalid Signature of Response" , 3);
                    }
                }
                else if ($respObject["result"] == "FAIL")
                {
                    throw new Exception($respObject["errorMessage"], $respObject["errorCode"]);
                }
                else
                {
                    assert(false);
                }
            }
        }
		catch (Exception $e)
        {
            throw $e;
        }

		return $respObject;
    }
}
?>
